
#ifndef __GLOBAL_H__
#define __GLOBAL_H__

#include <config.h>
#include <gnome.h>

#include "dummy.h"

extern GnomeMDI *mdi;
extern gboolean gtop_is_running;

extern GnomeUIInfo fileMenu [];

extern void gtop_mdi_init (void);
extern void gtop_mdi_start (gboolean);
extern void gtop_quit (void);

#endif
